@@ -1,7 +1,7 @@
 class Specinfra::Command::Redhat::Base::Yumrepo < Specinfra::Command::Linux::Base::Yumrepo
   class << self
     def check_exists(repository)
-      "yum repolist all -C | grep -E \"^#{escape(repository)}\(\\s\|$\|\\/)\""
+      "yum repolist all -C | grep -qsE \"^[\\!\\*]?#{escape(repository)}\(\\s\|$\|\\/)\""
     end
 
     def check_is_enabled(repository)
