@@ -27,6 +27,14 @@ describe get_command(:check_interface_has_ipv4_address, 'vtnet0', '192.168.0.123
   it { should eq "ifconfig vtnet0 inet | grep 'inet 192\\.168\\.0\\.123 '" }
 end
 
+describe get_command(:get_interface_ipv4_address, 'vtnet0') do
+  it { should eq "ifconfig vtnet0 inet | grep inet | awk '{print $2}'" }
+end
+
+describe get_command(:get_interface_ipv6_address, 'vtnet0') do
+  it { should eq "ifconfig vtnet0 inet6 | grep inet6 | awk '{print $2$3$4}' | sed 's/prefixlen/\//'; exit" }
+end
+
 describe get_command(:get_interface_link_state, 'vtnet0') do
   it { should eq %Q{ifconfig -u vtnet0 2>&1 | awk -v s=up '/status:/ && $2 != "active" { s="down" }; END {print s}'} }
 end
